@@ -14,7 +14,7 @@
 
 import pickle, os, uuid
 
-version = '0.29.0'
+version = '0.30.0'
 
 build_types = ['plain', 'debug', 'debugoptimized', 'release']
 layouts = ['mirror', 'flat']
@@ -60,9 +60,9 @@ class UserStringOption(UserOption):
 
     def validate(self, value):
         if not isinstance(value, str):
-            raise MesonException('Value "%s" for string option "%s" is not a string.' % (str(newvalue), self.name))
+            raise MesonException('Value "%s" for string option "%s" is not a string.' % (str(value), self.name))
         if self.name == 'prefix' and not os.path.isabs(value):
-            raise MesonException('Prefix option must be an absolute path.')
+            raise MesonException('Prefix option value \'{0}\' must be an absolute path.'.format(value))
         if self.name in ('libdir', 'bindir', 'includedir', 'datadir', 'mandir', 'localedir') \
             and os.path.isabs(value):
             raise MesonException('Option %s must not be an absolute path.' % self.name)
@@ -154,7 +154,6 @@ class CoreData():
         self.compilers = {}
         self.cross_compilers = {}
         self.deps = {}
-        self.ext_progs = {}
         self.modules = {}
 
     def init_builtins(self, options):
