@@ -123,6 +123,7 @@ class Conf:
         booleans = '[true, false]'
         carr.append(['buildtype', 'Build type', self.coredata.get_builtin_option('buildtype'), build_types])
         carr.append(['warning_level', 'Warning level', self.coredata.get_builtin_option('warning_level'), warning_levels])
+        carr.append(['werror', 'Treat warnings as errors', self.coredata.get_builtin_option('werror'), booleans])
         carr.append(['strip', 'Strip on install', self.coredata.get_builtin_option('strip'), booleans])
         carr.append(['coverage', 'Coverage report', self.coredata.get_builtin_option('coverage'), booleans])
         carr.append(['use_pch', 'Precompiled headers', self.coredata.get_builtin_option('use_pch'), booleans])
@@ -182,7 +183,7 @@ class Conf:
 def run(args):
     args = mesonlib.expand_arguments(args)
     if not args:
-        sys.exit(1)
+        args = [os.getcwd()]
     options = parser.parse_args(args)
     if len(options.directory) > 1:
         print('%s <build directory>' % args[0])
